@@ -80,6 +80,7 @@ std::auto_ptr<mosca::image> vimos_bias_stack
 void vimos_bias_write_qc(cpl_propertylist * qc_param, 
                          const mosca::image& master_bias,
                          const std::vector<mosca::image>& biases,
+                         const mosca::image& first_raw_bias,
                          vimos_preoverscan& scan_corr,
                          size_t goodFrames, mosca::ccd_config& bias_ccd_config);
 
@@ -1148,7 +1149,8 @@ vmbias(PilSetOfFrames *sof, cpl_frameset *frameset,
         cpl_msg_error(cpl_func, "Cannot subtract pre/overscan");
         return EXIT_FAILURE;
     }
-    bias_images.clear();
+    //Leave the first raw bias, since it is used to compute some QC values.
+    bias_images.erase(bias_images.begin()+1, bias_images.end());
    
     /* Trimm pre/overscan */
     std::vector<mosca::image> bias_trimmed;
@@ -1203,8 +1205,8 @@ vmbias(PilSetOfFrames *sof, cpl_frameset *frameset,
 
     /* QC */
     cpl_propertylist * qc_param = cpl_propertylist_new();
-    vimos_bias_write_qc(qc_param, *master_bias, bias_trimmed, scan_corr,
-                        goodFrames, bias_ccd_config);
+    vimos_bias_write_qc(qc_param, *master_bias, bias_trimmed, bias_images[0],
+                        scan_corr, goodFrames, bias_ccd_config);
 
     /* Save product */
     //Append the QC param to the raw bias header 
@@ -1442,6 +1444,7 @@ std::auto_ptr<mosca::image> vimos_bias_stack
 void vimos_bias_write_qc(cpl_propertylist * qc_param, 
                          const mosca::image& master_bias,
                          const std::vector<mosca::image>& biases,
+                         const mosca::image& first_raw_bias,
                          vimos_preoverscan& scan_corr,
                          size_t goodFrames, mosca::ccd_config& bias_ccd_config)
 {
@@ -1467,6 +1470,7 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
     float *sample2 = NULL;
     float *sample3 = NULL;
     double *sample4 = NULL;
+    float *sample5 = NULL;
     double *diff = NULL;
     
     cpl_image * sample1_im = cpl_image_extract(biases[0].get_cpl_image(),
@@ -1475,9 +1479,13 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
     cpl_image * sample2_im = cpl_image_extract(biases[1].get_cpl_image(),
             winStartX, winStartY, 
             winStartX + winSizeX, winStartY + winSizeY);
+    cpl_image * sample5_im = cpl_image_extract(first_raw_bias.get_cpl_image(),
+            winStartX, winStartY, 
+            winStartX + winSizeX, winStartY + winSizeY);
     
     sample1 = cpl_image_get_data_float(sample1_im);
     sample2 = cpl_image_get_data_float(sample2_im);
+    sample5 = cpl_image_get_data_float(sample5_im);
 
     diff = (double *)cpl_malloc(winSizeX * winSizeY * sizeof(double));
 
@@ -1496,25 +1504,18 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
 
     meanValue = computeAverageFloat(sample1, winSizeX * winSizeY);
 
+    double meanValueRaw = computeAverageFloat(sample5, winSizeX * winSizeY);
+
     cpl_propertylist_append_double(qc_param, "ESO QC BIAS MEAN",
-                          meanValue+scan_corr.get_median_correction());
+                                   meanValueRaw);
     cpl_propertylist_set_comment(qc_param, "ESO QC BIAS MEAN",
                           "Mean bias level [ADU]");
 
-    cpl_propertylist_append_double(qc_param,  "ESO QC BIAS OVSCAN MEAN",
-                          meanValue);
-    cpl_propertylist_set_comment(qc_param, "ESO QC BIAS OVSCAN MEAN",
-                          "Mean bias level after pre/overscan subtraction [ADU]");
-
-    /* QC.RON */
+    /* Old ronValue computed here. It is used for other QC params */
 
     value = computeVarianceDouble2D(diff, winSizeX, winSizeY);
     ronValue = sqrt(value / 2);
 
-    cpl_propertylist_append_double(qc_param,  "ESO QC RON",
-                          ronValue);
-    cpl_propertylist_set_comment(qc_param, "ESO QC RON", "Read out noise [ADU]");
-
     /* QC.BIAS.FPN */
 
     cpl_image * sample3_im = cpl_image_extract(biases[1].get_cpl_image(),
@@ -1568,10 +1569,10 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
 
     /* QC.BIAS.MEDIAN */
 
-    value = medianPixelvalue(sample1, winSizeX * winSizeY);
+    value = medianPixelvalue(sample5, winSizeX * winSizeY);
 
     cpl_propertylist_append_double(qc_param, "ESO QC BIAS MEDIAN",
-                                   value+scan_corr.get_median_correction());
+                                   value);
     cpl_propertylist_set_comment(qc_param, "ESO QC BIAS MEDIAN",
                                  "Median bias level [ADU]");
 
@@ -1593,15 +1594,10 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
     meanValue = computeAverageDouble(sample4, winSizeX * winSizeY);
 
     cpl_propertylist_append_double(qc_param, "ESO QC BIAS MASTER MEAN",
-                          meanValue+scan_corr.get_median_correction());
+                          meanValue);
     cpl_propertylist_set_comment(qc_param, "ESO QC BIAS MASTER MEAN",
                                  "Mean master bias level [ADU]");
 
-    cpl_propertylist_append_double(qc_param, "ESO QC BIAS MASTER OVSCAN MEAN",
-                                   meanValue);
-    cpl_propertylist_set_comment(qc_param, "ESO QC BIAS MASTER OVSCAN MEAN",
-                 "Mean master bias level after pre/overscan subtraction[ADU]");
-
     /* QC.BIAS.MASTER.RMS */
 
     meanValue = computeAverageDouble(sample4, winSizeX * winSizeY);
@@ -1719,6 +1715,7 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
                                  "Median master bias level [ADU]");
 
     //Save computed readout noise
+    double avg_ron = 0;
     for(size_t iport = 0; iport< bias_ccd_config.nports(); ++iport)
     {
         std::ostringstream key_stream;
@@ -1727,7 +1724,15 @@ void vimos_bias_write_qc(cpl_propertylist * qc_param,
                                        bias_ccd_config.computed_ron(iport));
         cpl_propertylist_set_comment(qc_param, key_stream.str().c_str(),
                                      "Readout noise per port from overscan [ADU]");
+        avg_ron += bias_ccd_config.computed_ron(iport);
     }
+    avg_ron /= bias_ccd_config.nports();
+
+    /* QC.RON */
+    cpl_propertylist_append_double(qc_param,  "ESO QC RON",
+                          avg_ron);
+    cpl_propertylist_set_comment(qc_param, "ESO QC RON", "Read out noise [ADU]");
+
 
     cpl_image_delete(sample1_im);
     cpl_image_delete(sample2_im);
