@@ -44,7 +44,7 @@
 #include "vmmatrix.h"
 #include "vmmath.h"
 #include "vmfit.h"
-
+#include "cpl.h"
 
 /**
  * @name vimosFit
@@ -104,7 +104,7 @@ double *fit1DPoly(int polyDeg, VimosDpoint *list, int np,
     return(NULL);
   }
 
-/*  c = pil_malloc((polyDeg+1)*sizeof(double)) ; */
+/*  c = cpl_malloc((polyDeg+1)*sizeof(double)) ; */
 /* */
 /* check if space was allocated */
 /*  if (c == NULL) { */
@@ -141,7 +141,7 @@ double *fit1DPoly(int polyDeg, VimosDpoint *list, int np,
     return(NULL);
   }
   
-  c = pil_malloc((polyDeg+1)*sizeof(double)) ;
+  c = cpl_malloc((polyDeg+1)*sizeof(double)) ;
 
   /* check if space was allocated */
   if (c == NULL) {
@@ -250,7 +250,7 @@ double *fitSurfacePolynomial(VimosPixel *surface, int np, char *controlString,
   */
   
   nc = (1+polyDeg)*(2+polyDeg) / 2 ;
-  degxTab = pil_malloc(nc * sizeof(int)) ;
+  degxTab = cpl_malloc(nc * sizeof(int)) ;
 
  /* check if space was allocated */
   if (degxTab == NULL) {
@@ -258,7 +258,7 @@ double *fitSurfacePolynomial(VimosPixel *surface, int np, char *controlString,
     return(NULL);
   }
 
-  degyTab = pil_malloc(nc * sizeof(int)) ;
+  degyTab = cpl_malloc(nc * sizeof(int)) ;
   
   /* check if space was allocated */
   if (degyTab == NULL) {
@@ -344,7 +344,7 @@ double *fitSurfacePolynomial(VimosPixel *surface, int np, char *controlString,
  /*
   * Store coefficients for output in a single array
   */
-  c = (double*) pil_malloc(nc * sizeof(double)) ;
+  c = (double*) cpl_malloc(nc * sizeof(double)) ;
   /* check if space was allocated */
   if (c == NULL) {
     cpl_msg_error(modName, "Allocation Error");
@@ -378,8 +378,8 @@ double *fitSurfacePolynomial(VimosPixel *surface, int np, char *controlString,
     err /= (double)np ;
     *meanSquaredError = err ;
   }
-  pil_free(degxTab) ;
-  pil_free(degyTab) ;
+  cpl_free(degxTab) ;
+  cpl_free(degyTab) ;
   return c ;
 }
 
@@ -515,8 +515,8 @@ double *fitSurfaceMatrix(VimosPixel *surface, int np, char *controlString,
    */
   
   nc = (1+polyDeg)*(1+polyDeg);
-  degxTab = pil_malloc(nc * sizeof(int)) ;
-  degyTab = pil_malloc(nc * sizeof(int)) ;
+  degxTab = cpl_malloc(nc * sizeof(int)) ;
+  degyTab = cpl_malloc(nc * sizeof(int)) ;
   
   if (controlString == NULL) {
     i = 0 ;
@@ -578,7 +578,7 @@ double *fitSurfaceMatrix(VimosPixel *surface, int np, char *controlString,
   /*
     Store coefficients for output in a single array
   */
-  c = (double*) pil_malloc(nc * sizeof(double)) ;
+  c = (double*) cpl_malloc(nc * sizeof(double)) ;
   for (i = 0; i < nc; i++) {
     c[i] = mX->data[i] ;
   }
@@ -608,8 +608,8 @@ double *fitSurfaceMatrix(VimosPixel *surface, int np, char *controlString,
   }
 
 
-  pil_free(degxTab) ;
-  pil_free(degyTab) ;
+  cpl_free(degxTab) ;
+  cpl_free(degyTab) ;
   return c ;
 }
 
@@ -692,17 +692,17 @@ int buildupPolytabFromString(char *s, int polyDeg, int * degxTab, int *degyTab)
   /*
     Cut the string into tokens, get degrees for x and y
   */
-  s2 = pil_strdup(s) ;
+  s2 = cpl_strdup(s) ;
   token = strtok(s2," ") ;
   if (token == NULL) {
-    pil_free(s2) ;
+    cpl_free(s2) ;
     cpl_msg_error(modName, "No tokens have been found");
     pilErrno = 1;
     return(-1);
   }
   ret = sscanf(token, "(%d,%d)", &degx, &degy) ;
   if (ret != 2) {
-    pil_free(s2) ;
+    cpl_free(s2) ;
     cpl_msg_error(modName, "Not enough tokens have been found");
     pilErrno = 1;
     return(-1);
@@ -714,13 +714,13 @@ int buildupPolytabFromString(char *s, int polyDeg, int * degxTab, int *degyTab)
     token = strtok(NULL, " ") ;
     sscanf(token, "(%d,%d)", &degx, &degy) ;
     if (ret != 2) {
-      pil_free(s2) ;
+      cpl_free(s2) ;
       cpl_msg_error(modName, "Not enough tokens have been found");
       pilErrno = 1;
       return(-1);
     }
     if (degx+degy > polyDeg) {
-      pil_free(s2) ;
+      cpl_free(s2) ;
       cpl_msg_error(modName, 
         "The sum of degrees of x and y is greater then polynomial degree"); 
       pilErrno = 1;
@@ -732,7 +732,7 @@ int buildupPolytabFromString(char *s, int polyDeg, int * degxTab, int *degyTab)
     for (j = 0; j < i; j++) {
       if ((degxTab[j] == degx) && 
           (degyTab[j] == degy) ) {
-        pil_free(s2) ;
+        cpl_free(s2) ;
 	cpl_msg_error(modName, "Duplicates have been found");
 	pilErrno = 1;
         return(-1);
@@ -741,7 +741,7 @@ int buildupPolytabFromString(char *s, int polyDeg, int * degxTab, int *degyTab)
     degxTab[i] = degx ; 
     degyTab[i] = degy ;
   }
-  pil_free(s2) ;
+  cpl_free(s2) ;
   return(nc);
 }
 
@@ -763,7 +763,7 @@ double *fitSlopeRobust(VimosDpoint *list, int np)
   double *y ;
   int    i ;
   
-  x = pil_malloc(np * sizeof(double)) ;
+  x = cpl_malloc(np * sizeof(double)) ;
 
   /* check if space was allocated */
   if (x == NULL) {
@@ -772,7 +772,7 @@ double *fitSlopeRobust(VimosDpoint *list, int np)
   }
 
   /* check if space was allocated */
-  y = pil_malloc(np * sizeof(double)) ;
+  y = cpl_malloc(np * sizeof(double)) ;
   if (y == NULL) {
     cpl_msg_error(modName, "Allocation Error");
     return(NULL);
@@ -783,7 +783,7 @@ double *fitSlopeRobust(VimosDpoint *list, int np)
     y[i] = list[i].y ;
   }
   
-  c = pil_malloc(3 * sizeof(double)) ;
+  c = cpl_malloc(3 * sizeof(double)) ;
 
   /* check if space was allocated */
   if (c == NULL) {
@@ -796,8 +796,8 @@ double *fitSlopeRobust(VimosDpoint *list, int np)
     return(NULL);
   }
  
-  pil_free(x) ;
-  pil_free(y) ;
+  cpl_free(x) ;
+  cpl_free(y) ;
   return(c);
 }
 
@@ -837,7 +837,7 @@ static VimosBool robustLinearFit(double *x, double *y, int np,
 		chisq += temp ;
 	}
 
-	arr = pil_malloc(np * sizeof(double)) ;
+	arr = cpl_malloc(np * sizeof(double)) ;
 	sigb = sqrt(chisq/del);
 	b1   = bb ;
 
@@ -877,7 +877,7 @@ static VimosBool robustLinearFit(double *x, double *y, int np,
 		*a = aa ;
 		*b = bb ;
 		*abdev = abdevt / (double)np;
-		pil_free(arr);
+		cpl_free(arr);
 		return(VM_TRUE);
 	}
 
@@ -909,7 +909,7 @@ static VimosBool robustLinearFit(double *x, double *y, int np,
 		*a = aa_ls ;
 		*b = bb_ls ;
 		*abdev = -1.0 ;
-		pil_free(arr);
+		cpl_free(arr);
 		return(VM_FALSE);
 	}
 
@@ -941,7 +941,7 @@ static VimosBool robustLinearFit(double *x, double *y, int np,
 			b2=bb;
 		}
 	}
-	pil_free(arr) ;
+	cpl_free(arr) ;
 	*a=aa;
 	*b=bb;
 	*abdev=abdevt/np;
@@ -1064,7 +1064,7 @@ char *createVimosCtrlStr(int xord, int yord)
  /*
   *  Generate control string
   */
-  pos = controlString = (char *) pil_malloc((4*nCoeff+spacex+spacey)*
+  pos = controlString = (char *) cpl_malloc((4*nCoeff+spacex+spacey)*
                                             sizeof(char));
 
   for (i=0; i<=xord; i++) {
@@ -1253,7 +1253,7 @@ void gaussJordan(float **a, int n, float **b, int m)
                else if (iPivot[k] > 1)
                  {
                   puts("gaussJordan: Singular Matrix-1");
-                  exit(-1);
+                  abort();
                  }
 	      }
       ++(iPivot[iCol]);
@@ -1267,7 +1267,7 @@ void gaussJordan(float **a, int n, float **b, int m)
       if (a[iCol][iCol] == 0.0)
         {
          puts("gaussJordan: Singular Matrix-2");
-         exit(-1);
+         abort();
         }
       pivotInv = 1.0 / a[iCol][iCol];
       a[iCol][iCol] = 1.0;
@@ -1670,7 +1670,7 @@ void fit1DGauss(VimosFloatArray *xArray, VimosFloatArray *yArray,
   if ((nTerms < 3) || (nTerms > 6))
     {
      puts(" fit1DGauss: nTerms at least 3, at most 6");
-     exit(-1);
+     abort();
     }
 
   /* to work with curvefit it is better to have arrays. I transform to    */
