@@ -1,4 +1,4 @@
-/* $Id: vmmoswavecalib.c,v 1.2 2013-03-25 11:43:04 cgarcia Exp $
+/* $Id: vmmoswavecalib.c,v 1.2 2013/03/25 11:43:04 cgarcia Exp $
  *
  * This file is part of the VIMOS Pipeline
  * Copyright (C) 2002-2004 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: cgarcia $
- * $Date: 2013-03-25 11:43:04 $
+ * $Date: 2013/03/25 11:43:04 $
  * $Revision: 1.2 $
- * $Name: not supported by cvs2svn $
+ * $Name:  $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,6 +51,7 @@
 #include "vmfit.h"
 #include "vmmosutils.h"
 #include "vmmoswavecalib.h"
+#include "cpl.h"
 
 
 /**
@@ -401,7 +402,7 @@ int VmSpDerDispOld(VimosImage *inputImage, VimosExtractionTable *extractionTable
 	    *  Free old array of coefficients, if exists 
 	    */
 	   if (coeffs != NULL) {
-	     pil_free(coeffs);
+	     cpl_free(coeffs);
 	     coeffs = NULL;
 	   }
 
@@ -587,10 +588,10 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
   float                lambda2pix;
   float                mm2pix;
   float                pixWidth;
-  float                lambdaWidth;
+/*  float                lambdaWidth; */
   float                pixelCen, pixelLo, pixelHi;
   float               *check[3];
-  int                  windowWidth;
+/*  int                  windowWidth; */
   
   double              *coeffs = NULL;
   double               datVal;
@@ -653,7 +654,7 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
   
   numLines = lineCat->cols->len;
   wLen = findColInTab(lineCat, "WLEN");
-  lines = pil_malloc(numLines * sizeof(double));
+  lines = cpl_malloc(numLines * sizeof(double));
 
   for (j = 0; j < numLines; j++)
     lines[j] = wLen->colValue->fArray[j];
@@ -670,9 +671,9 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
        numRows = slit->numRows;
 
        pixWidth = mm2pix * slit->width + widthBuffer;
-       lambdaWidth = pixWidth / lambda2pix;
+  /*     lambdaWidth = pixWidth / lambda2pix; 
        if (arcWidth < 0) windowWidth = 3*pixWidth;
-       else              windowWidth = arcWidth;
+       else              windowWidth = arcWidth; */
 
        min = max = slit->ccdY->data[0];
        for (i = 1; i < numRows; i++) {
@@ -744,12 +745,12 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
 	         buffer[j].x = output[1][j] - lambdaCen;
 	         buffer[j].y = output[0][j] - nPixBelow - 1;
 	       }
-               pil_free(output[0]);
-               pil_free(output[1]);
-               pil_free(output);
+               cpl_free(output[0]);
+               cpl_free(output[1]);
+               cpl_free(output);
              }
 
-             pil_free(peaks);
+             cpl_free(peaks);
 
            }
            else
@@ -763,7 +764,7 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
 	      */
 
 	     if (coeffs != NULL) {
-	       pil_free(coeffs);
+	       cpl_free(coeffs);
 	       coeffs = NULL;
 	     }
 
@@ -803,9 +804,9 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
         * be the case, due to misalignments).
         */
 
-       check[0] = pil_malloc(numRows * sizeof(float));
-       check[1] = pil_malloc(numRows * sizeof(float));
-       check[2] = pil_malloc(numRows * sizeof(float));
+       check[0] = cpl_malloc(numRows * sizeof(float));
+       check[1] = cpl_malloc(numRows * sizeof(float));
+       check[2] = cpl_malloc(numRows * sizeof(float));
 
        lambdaChecklo = lambdaCen - (nPixBelow / lambda2pix) / 2;
        lambdaCheckhi = lambdaCen + (nPixAbove / lambda2pix) / 2;
@@ -846,9 +847,9 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
          }
        }
 
-       pil_free(check[0]);
-       pil_free(check[1]);
-       pil_free(check[2]);
+       cpl_free(check[0]);
+       cpl_free(check[1]);
+       cpl_free(check[2]);
 
        if (invalidFit) {
          totInvalidFit += invalidFit;
@@ -861,7 +862,7 @@ int VmSpDerDisp(VimosImage *inputImage, VimosExtractionTable *extractionTable,
 
   deleteDpoint(buffer);
   deleteFloatArray(spectrum);
-  pil_free(lines);
+  cpl_free(lines);
 
   if (totInvalidFit == totNumRows) {
     cpl_msg_error(modName, "The IDS fit failed in all slit rows!");
@@ -957,7 +958,7 @@ int VmSpDispMatrix(VimosExtractionTable *extractionTable,
     while (slit) {
 
       numRows = slit->numRows;
-      coeff = (double *) pil_malloc(numRows*sizeof(double));
+      coeff = (double *) cpl_malloc(numRows*sizeof(double));
 
       /* 
        *  Skip columns where the solution is not available 
@@ -984,7 +985,7 @@ int VmSpDispMatrix(VimosExtractionTable *extractionTable,
         }
         slitDone++;
 
-        pil_free(coeff);
+        cpl_free(coeff);
       }
       slit = slit->next;
 
@@ -1436,8 +1437,8 @@ VimosDpoint *getWavIntervals(VimosTable *lineCat, float width)
 
   if (wLen) {
     numLines = lineCat->cols->len;
-    start    = (double *) pil_malloc(numLines*sizeof(double));
-    end      = (double *) pil_malloc(numLines*sizeof(double));
+    start    = (double *) cpl_malloc(numLines*sizeof(double));
+    end      = (double *) cpl_malloc(numLines*sizeof(double));
    /*
     *  First interval
     */
@@ -1463,8 +1464,8 @@ VimosDpoint *getWavIntervals(VimosTable *lineCat, float width)
       cpl_msg_debug(modName, "from %f to %f", interval->x, interval->y);
       interval = interval->next;
     }
-    pil_free(start);
-    pil_free(end);
+    cpl_free(start);
+    cpl_free(end);
   }
   return(wavIntervals);
 }
@@ -1671,10 +1672,10 @@ VimosDistModel1D *findMaxMatchIndex(VimosDistModel1D *lambdaToCcd,
         *  Get max variation for each polynomial coefficient.
         */
     
-        if ((coeffRange = pil_calloc(nCoeff, sizeof(double)))) {
+        if ((coeffRange = cpl_calloc(nCoeff, sizeof(double)))) {
           coeffRange[0] = pixRange;
 
-          if ((coeffStep = pil_calloc(nCoeff, sizeof(double)))) {
+          if ((coeffStep = cpl_calloc(nCoeff, sizeof(double)))) {
             coeffStep[0] = ((float) pixRange)/nStep;
 
             for (i = 1; i < nCoeff; i++) {
@@ -1694,7 +1695,7 @@ VimosDistModel1D *findMaxMatchIndex(VimosDistModel1D *lambdaToCcd,
                 }
                 start->offset = grid->offset;
     
-                if ((count = pil_calloc(nCoeff, sizeof(int)))) {
+                if ((count = cpl_calloc(nCoeff, sizeof(int)))) {
                   for (i = 1; i < nCoeff; i++) count[i] = 1;
                  /*
                   *  Find best Match Index in a n-dimensional grid
@@ -1734,15 +1735,15 @@ VimosDistModel1D *findMaxMatchIndex(VimosDistModel1D *lambdaToCcd,
                       }
                     }
                   }
-                  pil_free(count);
+                  cpl_free(count);
                 }
                 deleteDistModel1D(start);
               }
               deleteDistModel1D(grid);
             }
-            pil_free(coeffStep);
+            cpl_free(coeffStep);
           }
-          pil_free(coeffRange);
+          cpl_free(coeffRange);
         }
         forgetWavIntervals(wavIntervals);
       }
@@ -1859,25 +1860,25 @@ double **identPeaks(double *peak, int npeaks, double *line, int nlines,
   int      max, maxpos, minl, mink;
   int      ambiguous;
   int      npeaks_lo, npeaks_hi;
-  int     *peak_lo    = pil_malloc(npeaks * sizeof(int));
-  int     *peak_hi    = pil_malloc(npeaks * sizeof(int));
-  int    **ident      = pil_malloc(npeaks * sizeof(int *));
-  int     *nident     = pil_calloc(npeaks, sizeof(int));
-  int     *lident     = pil_calloc(nlines, sizeof(int));
+  int     *peak_lo    = cpl_malloc(npeaks * sizeof(int));
+  int     *peak_hi    = cpl_malloc(npeaks * sizeof(int));
+  int    **ident      = cpl_malloc(npeaks * sizeof(int *));
+  int     *nident     = cpl_calloc(npeaks, sizeof(int));
+  int     *lident     = cpl_calloc(nlines, sizeof(int));
 
-  double **output     = pil_calloc(2, sizeof(double *));
-  double  *xpos       = pil_calloc(npeaks, sizeof(double));
-  double  *lambda     = pil_calloc(npeaks, sizeof(double));
-  int     *ilambda    = pil_calloc(npeaks, sizeof(int));
-  double  *tmp_xpos    = pil_calloc(npeaks, sizeof(double));
-  double  *tmp_lambda  = pil_calloc(npeaks, sizeof(double));
-  double  *tmp_ilambda = pil_calloc(npeaks, sizeof(double));
-  int     *flag       = pil_calloc(npeaks, sizeof(int));
+  double **output     = cpl_calloc(2, sizeof(double *));
+  double  *xpos       = cpl_calloc(npeaks, sizeof(double));
+  double  *lambda     = cpl_calloc(npeaks, sizeof(double));
+  int     *ilambda    = cpl_calloc(npeaks, sizeof(int));
+  double  *tmp_xpos    = cpl_calloc(npeaks, sizeof(double));
+  double  *tmp_lambda  = cpl_calloc(npeaks, sizeof(double));
+  double  *tmp_ilambda = cpl_calloc(npeaks, sizeof(double));
+  int     *flag       = cpl_calloc(npeaks, sizeof(int));
   int      n = 0;
   int      nn;
   int      nseq       = 0;
   int      gap;
-  int     *seq_length = pil_calloc(npeaks, sizeof(int));
+  int     *seq_length = cpl_calloc(npeaks, sizeof(int));
   int      found;
 
 
@@ -1886,7 +1887,7 @@ double **identPeaks(double *peak, int npeaks, double *line, int nlines,
   output[1] = lambda;
 
   for (i = 0; i < npeaks; i++)
-    ident[i] = pil_malloc(3 * npeaks * sizeof(int));
+    ident[i] = cpl_malloc(3 * npeaks * sizeof(int));
 
 
   /*
@@ -2270,25 +2271,25 @@ double **identPeaks(double *peak, int npeaks, double *line, int nlines,
 **************************************************/
 
   for (i = 0; i < npeaks; i++)
-    pil_free(ident[i]);
-  pil_free(ident);
-  pil_free(nident);
-  pil_free(lident);
-  pil_free(ilambda);
-  pil_free(tmp_xpos);
-  pil_free(tmp_lambda);
-  pil_free(tmp_ilambda);
-  pil_free(peak_lo);
-  pil_free(flag);
-  pil_free(seq_length);
-  pil_free(peak_hi);
+    cpl_free(ident[i]);
+  cpl_free(ident);
+  cpl_free(nident);
+  cpl_free(lident);
+  cpl_free(ilambda);
+  cpl_free(tmp_xpos);
+  cpl_free(tmp_lambda);
+  cpl_free(tmp_ilambda);
+  cpl_free(peak_lo);
+  cpl_free(flag);
+  cpl_free(seq_length);
+  cpl_free(peak_hi);
 
   *identified = n;
 
   if (n == 0) {
-    pil_free(output[0]);
-    pil_free(output[1]);
-    pil_free(output);
+    cpl_free(output[0]);
+    cpl_free(output[1]);
+    cpl_free(output);
     return NULL;
   }
 
@@ -2329,7 +2330,7 @@ double *collectPeaks(float *row, int length,
   float   min;
   float  *smo;
   float  *flat;
-  double *peak   = pil_calloc(length/2, sizeof(double));
+  double *peak   = cpl_calloc(length/2, sizeof(double));
 
 
   /*
@@ -2338,7 +2339,7 @@ double *collectPeaks(float *row, int length,
    */
 
   if (width > 3) {
-    smo = pil_calloc(length, sizeof(float));
+    smo = cpl_calloc(length, sizeof(float));
     start = width / 2;
     end = length - width / 2;
     for (i = 0; i < start; i++)
@@ -2360,7 +2361,7 @@ double *collectPeaks(float *row, int length,
    * Pass a min filter to subtract the continuum
    */
 
-  flat = pil_calloc(length, sizeof(float));
+  flat = cpl_calloc(length, sizeof(float));
   start = minbox / 2;
   end = length - minbox / 2;
 
@@ -2373,7 +2374,7 @@ double *collectPeaks(float *row, int length,
   }
 
   if (width > 3) {
-    pil_free(smo);
+    cpl_free(smo);
   }
 
   for (i = 0; i < start; i++)
@@ -2406,10 +2407,10 @@ double *collectPeaks(float *row, int length,
 
   *npeak = n;
 
-  pil_free(flat);
+  cpl_free(flat);
 
   if (n == 0) {
-    pil_free(peak);
+    cpl_free(peak);
     return NULL;
   }
 
@@ -2432,7 +2433,7 @@ double *collectPeaks_double(double *row, int length,
   float   min;
   double *smo;
   float  *flat;
-  double *peak   = pil_calloc(length/2, sizeof(double));
+  double *peak   = cpl_calloc(length/2, sizeof(double));
 
 
   /*
@@ -2441,7 +2442,7 @@ double *collectPeaks_double(double *row, int length,
    */
 
   if (width > 3) {
-    smo = pil_calloc(length, sizeof(float));
+    smo = cpl_calloc(length, sizeof(float));
     start = width / 2;
     end = length - width / 2;
     for (i = 0; i < start; i++)
@@ -2463,7 +2464,7 @@ double *collectPeaks_double(double *row, int length,
    * Pass a min filter to subtract the continuum
    */
 
-  flat = pil_calloc(length, sizeof(float));
+  flat = cpl_calloc(length, sizeof(float));
   start = minbox / 2;
   end = length - minbox / 2;
 
@@ -2476,7 +2477,7 @@ double *collectPeaks_double(double *row, int length,
   }
 
   if (width > 3) {
-    pil_free(smo);
+    cpl_free(smo);
   }
 
   for (i = 0; i < start; i++)
@@ -2509,10 +2510,10 @@ double *collectPeaks_double(double *row, int length,
 
   *npeak = n;
 
-  pil_free(flat);
+  cpl_free(flat);
 
   if (n == 0) {
-    pil_free(peak);
+    cpl_free(peak);
     return NULL;
   }
 
